"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplateRootPathMapping = exports.getTemplateFrameworkMapping = exports.getTemplateUrlMapping = exports.createApp = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const chalk = require("chalk");
const init_1 = require("./init");
async function createApp(templateAlias, projectName, protocol) {
    try {
        console.log(`- Initializing dapp in ${projectName}`);
        const url = getTemplateUrlMapping(templateAlias);
        (0, child_process_1.execSync)(`git clone --quiet ${url} ${projectName}`);
        console.log(`${chalk.green("✓")} ${chalk.cyan(templateAlias)} dapp initialized`);
        cleanUpFiles(projectName);
        const framework = getTemplateFrameworkMapping(templateAlias);
        const rootPath = getTemplateRootPathMapping(templateAlias);
        process.chdir(projectName);
        await (0, init_1.init)(projectName, protocol, rootPath, framework, true);
        process.chdir("..");
        console.log(`${chalk.green("✓")} ${chalk.cyan(templateAlias)} dapp created in ${projectName} 🚀`);
    }
    catch (error) {
        console.log(`✖️  Error: ${error.message}`);
    }
}
exports.createApp = createApp;
function cleanUpFiles(folderName) {
    fs_1.default.rmSync(path_1.default.join(process.cwd(), folderName, ".git"), {
        recursive: true,
        force: true,
    });
}
function getTemplateUrlMapping(alias) {
    if (alias === "Portfolio") {
        return "https://github.com/spheronFdn/portfolio-template";
    }
    else if (alias === "React") {
        return "https://github.com/spheronFdn/react-boilerplate";
    }
    else if (alias === "Next.js") {
        return "https://github.com/spheronFdn/next-boilerplate";
    }
    throw new Error("Mapping for template not found");
}
exports.getTemplateUrlMapping = getTemplateUrlMapping;
function getTemplateFrameworkMapping(alias) {
    if (alias === "Portfolio") {
        return init_1.FrameworkOptions.Next;
    }
    else if (alias === "React") {
        return init_1.FrameworkOptions.React;
    }
    else if (alias === "Next.js") {
        return init_1.FrameworkOptions.Next;
    }
    throw new Error("Mapping for template not found");
}
exports.getTemplateFrameworkMapping = getTemplateFrameworkMapping;
function getTemplateRootPathMapping(alias) {
    if (alias === "Portfolio" || alias === "React" || alias === "Next.js") {
        return "./";
    }
    return "";
}
exports.getTemplateRootPathMapping = getTemplateRootPathMapping;
