"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createOrganization = void 0;
const axios_1 = __importDefault(require("axios"));
const configuration_1 = __importDefault(require("../configuration"));
const utils_1 = require("../utils");
const create_configuration_1 = require("./create-configuration");
const spinner_1 = __importDefault(require("../outputs/spinner"));
async function createOrganization(name, username, type) {
    var _a;
    const spinner = new spinner_1.default();
    try {
        spinner.spin("Creating organization ");
        if (!(await (0, utils_1.fileExists)(configuration_1.default.configFilePath))) {
            await (0, create_configuration_1.createConfiguration)();
        }
        const jwtToken = await (0, utils_1.readFromJsonFile)("jwtToken", configuration_1.default.configFilePath);
        if (!jwtToken) {
            console.log("For creating new organisation, you need to login to Spheron first");
            return;
        }
        const organizationResponse = await axios_1.default.post(`${configuration_1.default.spheronServerAddress}/v1/organization`, {
            name,
            username,
            appType: type,
        }, {
            headers: {
                authorization: `Bearer ${jwtToken}`,
            },
        });
        if (organizationResponse.status != 201 ||
            ((_a = organizationResponse.data) === null || _a === void 0 ? void 0 : _a.success) == false) {
            throw new Error("Failed to create an organization");
        }
        const organization = organizationResponse.data.organization;
        await (0, utils_1.writeToJsonFile)("organization", organization._id, configuration_1.default.configFilePath);
        spinner.success(`Organization ${name} is created`);
    }
    catch (error) {
        console.log(`✖️  Error: ${error.message}`);
        throw error;
    }
    finally {
        spinner.stop();
    }
}
exports.createOrganization = createOrganization;
