"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.login = void 0;
const http_1 = __importDefault(require("http"));
const open_1 = __importDefault(require("open"));
const axios_1 = __importDefault(require("axios"));
const utils_1 = require("../utils");
const configuration_1 = __importDefault(require("../configuration"));
const spinner_1 = __importDefault(require("../outputs/spinner"));
let server;
async function login(provider) {
    const spinner = new spinner_1.default();
    spinner.spin(`Waiting for ${provider} authentication to be completed `);
    server = http_1.default.createServer();
    server.listen(0, "127.0.0.1", async () => {
        const { port } = server.address();
        const baseURL = `${configuration_1.default.spheronServerAddress}/auth/${provider}/cli/login`;
        const fullURL = baseURL + `?port=${port}`;
        let loginError = false;
        try {
            await Promise.all([
                new Promise((resolve, reject) => {
                    server.once("request", async (req, res) => {
                        var _a;
                        try {
                            const code = (_a = req.url) === null || _a === void 0 ? void 0 : _a.split("&")[0].split("=")[1];
                            const verify = await axios_1.default.get(`${configuration_1.default.spheronServerAddress}/auth/${provider}/cli/verify-token/${code}?port=${port}`, {
                                headers: {
                                    Accept: "application/json",
                                },
                            });
                            if (verify.status != 200 || !verify.data.jwtToken) {
                                loginError = true;
                                throw new Error("Verification of token failed");
                            }
                            const jwt = verify.data.jwtToken;
                            const organizationId = verify.data.organizationId;
                            const email = verify.data.email;
                            res.setHeader("connection", "close");
                            res.statusCode = 302;
                            const successLocationRedirect = new URL(`${configuration_1.default.spheronFrontendAddress}/#/notifications/cli-login?email=${encodeURIComponent(email)}`);
                            res.setHeader("location", successLocationRedirect.href);
                            res.end();
                            await (0, utils_1.writeToJsonFile)("jwtToken", jwt, configuration_1.default.configFilePath);
                            await (0, utils_1.writeToJsonFile)("organization", organizationId, configuration_1.default.configFilePath);
                            resolve();
                        }
                        catch (e) {
                            console.log(`✖️  Error occured while logging in. Check if you have created an account on Spheron. You need to sign up first with ${provider} connection to be able to login with CLI.`);
                            spinner.stop();
                            process.exit(0);
                        }
                    });
                    server.once("error", reject);
                }),
                (0, open_1.default)(fullURL),
            ]);
        }
        catch (error) {
            loginError = true;
        }
        finally {
            server.close();
            if (loginError) {
                console.log(`✖️  Error occured while logging in`);
            }
            else {
                spinner.success(`${provider} authentication completed`);
            }
            spinner.stop();
            process.exit(0);
        }
    });
}
exports.login = login;
