#! /usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs = require("yargs");
const configuration_1 = __importDefault(require("./configuration"));
const command_handler_1 = require("./command-handler");
const init_1 = require("./commands/init");
(async () => {
    console.log(`Spheron CLI ${configuration_1.default.version}\n`);
    const options = yargs
        .command("login", "Logs into yout Spheron account", (yargs) => {
        yargs
            .option("github", {
            describe: "Login using Github credentials",
        })
            .option("gitlab", {
            describe: "Login using Gitlab credentials",
        })
            .option("bitbucket", {
            describe: "Login using Bitbucket credentials",
        })
            .version(false)
            .usage("Usage: $0 login [--github|--gitlab|--bitbucket]")
            .wrap(100)
            .help();
    })
        .command("logout", "Logs out of your account", (yargs) => {
        yargs.version(false).usage("Usage: $0 logout").help();
    })
        .command("upload", "Upload", (yargs) => {
        yargs
            .option("path", {
            describe: "Relative path to file",
            demandOption: false,
        })
            .option("protocol", {
            describe: "Upload protocol",
            choices: ["arweave", "filecoin", "ipfs"],
        })
            .option("project", {
            describe: "Project name",
        })
            .option("organization", {
            describe: "Organization where project will be created",
        })
            .version(false)
            .usage(`Usage: $0 upload --path <file_path> --protocol [arweave| filecoin| ipfs] [--project <project_name>] [--organization <organizationId>]`)
            .wrap(100)
            .help();
    })
        .command("publish", "Upload your project setup in spheron.json", (yargs) => {
        yargs
            .version(false)
            .usage(`Usage: $0 publish [--organization <organizationId>]`)
            .help();
    })
        .command("create-organization", "Create organization", (yargs) => {
        yargs
            .option("name", {
            describe: "Name of the organization",
        })
            .option("username", {
            describe: "Username of the organization",
        })
            .version(false)
            .usage(`Usage: $0 create-organization --name <organization_name> --username <username>`)
            .wrap(100)
            .help();
    })
        .command("init", "Spheron file initialization in project", (yargs) => {
        yargs
            .option("protocol", {
            describe: "Protocol that will be used for uploading ",
            choices: ["arweave", "filecoin", "ipfs"],
        })
            .option("project", {
            describe: "Project name",
        })
            .option("path", {
            describe: "Relative path to uploading content",
        })
            .option("framework", {
            describe: "Framework choice for the project",
            choices: Object.values(init_1.FrameworkOptions),
            default: "static",
        })
            .version(false)
            .usage(`Usage: $0 init --protocol <protocol> [--project <project_name>] [--path <path>] [--framework <framework>]`)
            .wrap(150)
            .help();
    })
        .command("create-dapp", "Create a template application which can run on Spheron out of the box", (yargs) => {
        yargs
            .version(false)
            .usage(`Usage: $0 create-dapp <name>`)
            .wrap(100)
            .help();
    }).argv;
    await (0, command_handler_1.commandHandler)(options);
})();
