"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileTypeEnum = exports.mapProtocolToUserReadable = exports.deleteKeyFromJson = exports.writeToJsonFile = exports.readFromJsonFile = exports.getFileType = exports.fileExists = void 0;
const fs_1 = __importDefault(require("fs"));
async function fileExists(path) {
    try {
        await fs_1.default.promises.stat(path);
        return true;
    }
    catch (err) {
        return false;
    }
}
exports.fileExists = fileExists;
async function getFileType(path) {
    try {
        const stats = await fs_1.default.promises.stat(path);
        if (stats.isDirectory()) {
            return FileTypeEnum.DIRECTORY;
        }
        else {
            return FileTypeEnum.FILE;
        }
    }
    catch (err) {
        console.error(err);
        throw new Error("Error while reading file");
    }
}
exports.getFileType = getFileType;
async function readFromJsonFile(key, path) {
    let config = {};
    try {
        const fileContents = await fs_1.default.promises.readFile(path, "utf-8");
        config = JSON.parse(fileContents);
    }
    catch (err) {
        console.error("Error reading Spheron config file:", err.message);
        return undefined;
    }
    return config[key];
}
exports.readFromJsonFile = readFromJsonFile;
async function writeToJsonFile(key, value, path, options) {
    let config = {};
    const opt = options ? options : "utf-8";
    try {
        await fs_1.default.promises.stat(path);
        const fileContents = await fs_1.default.promises.readFile(path, "utf-8");
        config = JSON.parse(fileContents);
    }
    catch (err) {
        await fs_1.default.promises.writeFile(path, "{}", opt);
    }
    config[key] = value;
    const jsonString = JSON.stringify(config, null, 2);
    await fs_1.default.promises.writeFile(path, jsonString, opt);
}
exports.writeToJsonFile = writeToJsonFile;
async function deleteKeyFromJson(key, path) {
    try {
        const fileContents = await fs_1.default.promises.readFile(path, "utf-8");
        const jsonConfig = JSON.parse(fileContents);
        delete jsonConfig[key];
        const jsonString = JSON.stringify(jsonConfig, null, 2);
        await fs_1.default.promises.writeFile(path, jsonString, "utf-8");
    }
    catch (err) {
        console.error(`Error deleting key ${key} from JSON file ${path}: ${err.message}`);
    }
}
exports.deleteKeyFromJson = deleteKeyFromJson;
function mapProtocolToUserReadable(protocol) {
    if (protocol === "ipfs") {
        return "IPFS";
    }
    else if (protocol === "filecoin") {
        return "Filecoin";
    }
    else if (protocol === "arweave") {
        return "Arweave";
    }
    return "IPFS";
}
exports.mapProtocolToUserReadable = mapProtocolToUserReadable;
var FileTypeEnum;
(function (FileTypeEnum) {
    FileTypeEnum["DIRECTORY"] = "directory";
    FileTypeEnum["FILE"] = "file";
})(FileTypeEnum = exports.FileTypeEnum || (exports.FileTypeEnum = {}));
